@@ -191,6 +191,9 @@ pub enum SyntaxError {
 
     ConstDeclarationsRequireInitialization,
 
+    DuplicatedRegExpFlags(char),
+    UnknownRegExpFlags,
+
     TS1003,
     TS1005,
     TS1009,
@@ -320,7 +323,9 @@ impl SyntaxError {
             SyntaxError::IllegalLanguageModeDirective => {
                 "Illegal 'use strict' directive in function with non-simple parameter list.".into()
             }
-            SyntaxError::UnaryInExp { .. } => "** cannot be applied to unary expression".into(),
+            SyntaxError::UnaryInExp { .. } => {
+                "'**' cannot be applied to unary/await expression.".into()
+            }
             SyntaxError::Hash => "Unexpected token '#'".into(),
             SyntaxError::LineBreakInThrow => "LineBreak cannot follow 'throw'".into(),
             SyntaxError::LineBreakBeforeArrow => {
@@ -508,6 +513,11 @@ impl SyntaxError {
                 "'const' declarations must be initialized".into()
             }
 
+            SyntaxError::DuplicatedRegExpFlags(flag) => {
+                format!("Duplicated regular expression flag '{}'.", flag).into()
+            }
+            SyntaxError::UnknownRegExpFlags => "Unknown regular expression flags.".into(),
+
             SyntaxError::TS1003 => "Expected an identifier".into(),
             SyntaxError::TS1005 => "Expected a semicolon".into(),
             SyntaxError::TS1009 => "Trailing comma is not allowed".into(),
